Param(
    [string]$url = "https://service-status.webex.com/customer/dashServices/891",
     [Parameter(Mandatory)]
     [String]$ValueLookup
)
[Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12
$prtg        = '' | select prtg
$results     = @()
$statis = @{
    Operational = 0
    degraded_performance = 1
	partial_outage = 2
}

Try{
    $response = Invoke-RestMethod $script:url | select -expand components
    #| Select componentName, status
    foreach ($comp in $response) {
        if (![string]::IsNullOrEmpty($comp.status)){
            $result = @{
                channel     = $comp.componentName
                value       = $statis[$comp.status]
                valuelookup = $ValueLookup
            }
            $results += $result
        }
    }
    $prtg.prtg        = '' | select result
    $prtg.prtg.result = $results
} catch {
    $prtg.prtg        = '' | select error
    $prtg.prtg.error  = 1
    $prtg.prtg | Add-Member -MemberType NoteProperty -Name 'text' -Value $null
    $prtg.prtg.text   = '{0} at line : {1}' -f $_.Exception.Message, $_.InvocationInfo.PositionMessage
} finally {
    $prtgJson = $prtg | ConvertTo-Json -Depth 5
    $prtgJson
    if ($prtg.prtg.error) {
        Exit 1
    } else {
        Exit 0
    }
}